@@ -137,3 +137,13 @@ def swipe(from_x, to_x, from_y, to_y, duration=500):
         duration: The time it will take to perform the swipe
     """
     send_input(f'swipe {from_x} {from_y} {to_x} {to_y} {duration}')
+
+
+def clear_app_cache(package_name):
+    """
+    Will clear an app's cache
+
+    Args:
+        package_name: the package name of the app you wish to clear it's cache
+    """
+    send_shell(f'pm clear {package_name}')
